@@ -9,7 +9,7 @@ NotDB Cloud is an API that allows you to read and write data from your machine t
 Full documentation is avaliable on [Github](https://github.com/nawafalqari/NotDB_Cloud#readme)
 '''
 
-from .app import is_secured
+from app import is_secured
 
-__version__ = '1.0.1'
+__version__ = '1.0.2'
 __all__ = ['is_secured']
\ No newline at end of file
